@@ -33,7 +33,6 @@
 
 struct _GgvPostScriptViewPrivate {
 	GtkWidget *gs;
-	GtkObject *hadj, *vadj;
 
 	GNOME_GGV_Size def_size;
 	GNOME_GGV_Orientation def_orientation;
@@ -42,6 +41,7 @@ struct _GgvPostScriptViewPrivate {
 	gboolean pan;
 	gdouble prev_x, prev_y;
 	gchar *tmp_name;
+	guint gconf_notify_id;
 
 	GgvMsgWindow *msg_win;
 	GgvSidebar *sidebar;
@@ -118,12 +118,11 @@ static const gchar *size_paths[] = {
 void
 get_status(GgvPostScriptView *ps_view, BonoboArg *arg)
 {
-	GtkGS *gs = GTK_GS(ps_view->priv->gs);
-	gchar *status;
+	const gchar *status;
 
 	g_assert(arg->_type == TC_CORBA_string);
 	
-	status = "GGV control status...";
+	status = GTK_GS(ps_view->priv->gs)->gs_status;;
 
 	*(CORBA_string *)arg->_value = CORBA_string_dup(status);
 }
@@ -150,21 +149,34 @@ static void
 set_file_items_sensitivity(GgvPostScriptView *ps_view, gboolean sens)
 {
 	gchar *prop_val = sens?"1":"0";
+	Bonobo_UIContainer container;
 
+	container = bonobo_ui_component_get_container (ps_view->priv->uic);
+	if (container == CORBA_OBJECT_NIL)
+		return;
+
+	bonobo_ui_component_freeze(ps_view->priv->uic, NULL);
 	bonobo_ui_component_set_prop(ps_view->priv->uic, "/commands/FileSaveMarked",
-                                     "sensitive", prop_val, NULL);
+								 "sensitive", prop_val, NULL);
 	bonobo_ui_component_set_prop(ps_view->priv->uic, "/commands/FilePrintMarked",
-                                     "sensitive", prop_val, NULL);
+								 "sensitive", prop_val, NULL);
 	bonobo_ui_component_set_prop(ps_view->priv->uic, "/commands/FilePrintAll",
-                                     "sensitive", prop_val, NULL);
+								 "sensitive", prop_val, NULL);
+	bonobo_ui_component_thaw(ps_view->priv->uic, NULL);
 }
 
 static void
-_set_page_item_sensitivity(GgvPostScriptView *ps_view, BonoboUIComponent *uic)
+_set_page_items_sensitivity(GgvPostScriptView *ps_view, BonoboUIComponent *uic)
 {
 	GtkGS *gs = GTK_GS(ps_view->priv->gs);
 	gchar *prop_val;
+	Bonobo_UIContainer container;
 
+	container = bonobo_ui_component_get_container (uic);
+	if (container == CORBA_OBJECT_NIL)
+		return;
+
+	bonobo_ui_component_freeze(uic, NULL);
 	prop_val = (gtk_gs_get_current_page(gs) >= gtk_gs_get_page_count(gs) - 1 ||
 				gtk_gs_get_current_page(gs) < 0)?
 		"0":"1";
@@ -181,14 +193,15 @@ _set_page_item_sensitivity(GgvPostScriptView *ps_view, BonoboUIComponent *uic)
 		"0":"1";
 	bonobo_ui_component_set_prop(uic, "/commands/LastPage",
 								 "sensitive", prop_val, NULL);
+	bonobo_ui_component_thaw(uic, NULL);
 }
 
 static void
-set_page_item_sensitivity(GgvPostScriptView *ps_view)
+set_page_items_sensitivity(GgvPostScriptView *ps_view)
 {
-	_set_page_item_sensitivity(ps_view, ps_view->priv->uic);
+	_set_page_items_sensitivity(ps_view, ps_view->priv->uic);
 	if(ps_view->priv->popup_uic != NULL)
-		_set_page_item_sensitivity(ps_view, ps_view->priv->popup_uic);
+		_set_page_items_sensitivity(ps_view, ps_view->priv->popup_uic);
 }
 
 static void
@@ -196,13 +209,17 @@ notify_page_count_change(GgvPostScriptView *ps_view)
 {
 	BonoboArg *arg;
 
-	set_page_item_sensitivity(ps_view);
+	set_page_items_sensitivity(ps_view);
+	set_file_items_sensitivity(ps_view, ggv_postscript_view_get_page_count(ps_view) > 0);
+	if(ps_view->priv->sidebar)
+		ggv_sidebar_create_page_list(ps_view->priv->sidebar);
 
 	arg = bonobo_arg_new(TC_CORBA_long);
-	BONOBO_ARG_SET_LONG(arg, gtk_gs_get_page_count(GTK_GS(ps_view->priv->gs)));
+	BONOBO_ARG_SET_LONG(arg, ggv_postscript_view_get_page_count(ps_view));
 	bonobo_event_source_notify_listeners(ps_view->priv->property_bag->es,
 										 "Bonobo/Property:change:page_count",
 										 arg, NULL);
+
 	bonobo_arg_release(arg);
 }
 
@@ -224,7 +241,7 @@ notify_page_change(GgvPostScriptView *ps_view)
 {
 	BonoboArg *arg;
 
-	set_page_item_sensitivity(ps_view);
+	set_page_items_sensitivity(ps_view);
 	ggv_sidebar_page_changed(ps_view->priv->sidebar,
 							 gtk_gs_get_current_page(GTK_GS(ps_view->priv->gs)));
 
@@ -248,6 +265,18 @@ notify_title_change(GgvPostScriptView *ps_view)
 	bonobo_arg_release(arg);
 }
 
+static void
+notify_status_change(GgvPostScriptView *ps_view)
+{
+	BonoboArg *arg;
+	arg = bonobo_arg_new(TC_CORBA_string);
+	get_status(ps_view, arg);
+	bonobo_event_source_notify_listeners(ps_view->priv->property_bag->es,
+										 "Bonobo/Property:change:status",
+										 arg, NULL);
+	bonobo_arg_release(arg);
+}
+
 void
 ggv_postscript_view_goto_page(GgvPostScriptView *ps_view, gint page)
 {
@@ -275,14 +304,14 @@ static void
 load_ps(GgvPostScriptView *ps_view, const gchar *fname)
 {
 	gtk_gs_load(GTK_GS(ps_view->priv->gs), fname);
-	ggv_sidebar_create_page_list(ps_view->priv->sidebar);
 	notify_title_change(ps_view);
 	notify_page_count_change(ps_view);
 	notify_orientation_change(ps_view);
 	ggv_postscript_view_goto_page(ps_view, 0);
 	notify_page_change(ps_view);
 	ggv_sidebar_update_coordinates(ps_view->priv->sidebar, 0.0, 0.0);
-	set_file_items_sensitivity(ps_view, ggv_postscript_view_get_current_page(ps_view) >= 0);
+	set_file_items_sensitivity(ps_view, ggv_postscript_view_get_page_count(ps_view) > 0);
+	notify_status_change(ps_view);
 }
 
 /*
@@ -455,7 +484,6 @@ load_ps_from_file (BonoboPersistFile *pf, const CORBA_char *filename,
 				   CORBA_Environment *ev, void *data)
 {
 	GgvPostScriptView *ps_view;
-	BonoboArg *arg;
 
 	g_return_val_if_fail (data != NULL, -1);
 	g_return_val_if_fail (GGV_IS_POSTSCRIPT_VIEW (data), -1);
@@ -662,7 +690,7 @@ static gboolean
 save_file_sel_delete_event(GtkWidget *widget, GdkEventAny *e, gpointer data)
 {
 	gtk_widget_hide(widget);
-	return FALSE;
+	return TRUE;
 }
 
 static void
@@ -678,9 +706,10 @@ save_file_sel_ok_clicked(GtkWidget *widget, gpointer data)
 	doc = ggv_postscript_view_get_ps(ps_view, active_rows);
 	g_free(active_rows);
 
+	/* get file name */
+	gtk_widget_hide(ps_view->priv->save_file_sel);
+
 	if(doc != NULL) {
-		/* get file name */
-		gtk_widget_hide(ps_view->priv->save_file_sel);
 		fname = gtk_file_selection_get_filename(GTK_FILE_SELECTION(ps_view->priv->save_file_sel));
 
 		if(ggv_file_readable(fname)) {
@@ -909,6 +938,7 @@ sync_orientation_items(GgvPostScriptView *ps_view)
 	gint i;
 	gboolean val, orient_state;
 
+	bonobo_ui_component_freeze(ps_view->priv->uic, NULL);
 	val = gtk_gs_get_override_orientation(GTK_GS(ps_view->priv->gs));
 	bonobo_ui_component_set_prop(ps_view->priv->uic, orientation_paths[0],
 								 "state", val?"1":"0", NULL);
@@ -919,6 +949,7 @@ sync_orientation_items(GgvPostScriptView *ps_view)
 		bonobo_ui_component_set_prop(ps_view->priv->uic, orientation_paths[i],
 									 "state", orient_state?"1":"0", NULL);
 	}
+	bonobo_ui_component_thaw(ps_view->priv->uic, NULL);
 }
 
 static void
@@ -930,6 +961,7 @@ sync_size_items(GgvPostScriptView *ps_view)
 
 	paths = size_paths;
 
+	bonobo_ui_component_freeze(ps_view->priv->uic, NULL);
 	val = gtk_gs_get_override_size(GTK_GS(ps_view->priv->gs));
 	bonobo_ui_component_set_prop(ps_view->priv->uic, paths[0],
 								 "state", val?"1":"0", NULL);
@@ -940,6 +972,7 @@ sync_size_items(GgvPostScriptView *ps_view)
 		bonobo_ui_component_set_prop(ps_view->priv->uic, paths[i],
 									 "state", size_state?"1":"0", NULL);
 	}
+	bonobo_ui_component_thaw(ps_view->priv->uic, NULL);
 }
 
 BonoboUIVerb ggv_postscript_view_verbs[] = {
@@ -957,8 +990,6 @@ BonoboUIVerb ggv_postscript_view_verbs[] = {
 static void
 ggv_postscript_view_create_ui(GgvPostScriptView *ps_view)
 {
-	BonoboUINode *ui_root;
-	GgvPostScriptViewClass *klass = GGV_POSTSCRIPT_VIEW_CLASS(G_OBJECT_GET_CLASS(ps_view));
 	gint i;
 
 	g_return_if_fail(ps_view != NULL);
@@ -968,15 +999,19 @@ ggv_postscript_view_create_ui(GgvPostScriptView *ps_view)
 	bonobo_ui_util_set_ui(ps_view->priv->uic, DATADIR,
 						  "ggv-postscript-view-ui.xml", 
 						  "GGV", NULL);
+	bonobo_ui_component_freeze(ps_view->priv->uic, NULL);
 	bonobo_ui_component_set_prop(ps_view->priv->uic, "/Sidebar",
 								 "placement", ggv_right_panel?"right":"left", NULL);
 	bonobo_ui_component_set_prop(ps_view->priv->uic, "/Sidebar",
 								 "hidden", ggv_panel?"0":"1", NULL);
-	bonobo_ui_component_object_set(ps_view->priv->uic, "/Sidebar/GgvSidebar",
-								   BONOBO_OBJREF(ps_view->priv->sidebar), NULL);
 	bonobo_ui_component_add_verb_list_with_data(ps_view->priv->uic,
 												ggv_postscript_view_verbs,
 												ps_view);
+	bonobo_ui_component_thaw(ps_view->priv->uic, NULL);
+#if 1
+	bonobo_ui_component_object_set(ps_view->priv->uic, "/Sidebar/GgvSidebar",
+								   BONOBO_OBJREF(ps_view->priv->sidebar), NULL);
+#endif
 
 	for(i = 1; size_paths[i]; i++) 
 		bonobo_ui_component_add_listener(ps_view->priv->uic,
@@ -991,8 +1026,9 @@ ggv_postscript_view_create_ui(GgvPostScriptView *ps_view)
 									 listener_Toggle_cb, ps_view);
 	bonobo_ui_component_add_listener(ps_view->priv->uic, "OverrideOrientation",
 									 listener_Toggle_cb, ps_view);
-
-	set_page_item_sensitivity(ps_view);
+	set_file_items_sensitivity(ps_view,
+							   ggv_postscript_view_get_page_count(ps_view) > 0);
+	set_page_items_sensitivity(ps_view);
 	sync_orientation_items(ps_view);
 	sync_size_items(ps_view);
 }
@@ -1116,10 +1152,13 @@ ggv_postscript_view_get_prop(BonoboPropertyBag *bag,
         case GTK_GS_ORIENTATION_SEASCAPE:
 			w = gs->ury - gs->lly;
 			break;
+		default:
+			w = 0;
+			break;
 		}
 		w = MAX(w, 0);
 		*(CORBA_long *)arg->_value = w;
-		break;
+		break;		
 	}
 	case PROP_HEIGHT: {
 		CORBA_float h;
@@ -1138,6 +1177,8 @@ ggv_postscript_view_get_prop(BonoboPropertyBag *bag,
         case GTK_GS_ORIENTATION_SEASCAPE:
 			h = gs->urx - gs->llx;
 			break;
+		default:
+			h = 0;
 		}
 		h = MAX(h, 0);
 		*(CORBA_long *)arg->_value = h;
@@ -1356,7 +1397,9 @@ ggv_postscript_view_get_object(BonoboItemContainer *item_container,
 
 	corba_object = bonobo_object_corba_objref (object);
 
-	return bonobo_object_dup_ref (corba_object, ev);
+	corba_object = bonobo_object_dup_ref(corba_object, ev);
+
+	return corba_object;
 }
 
 BonoboObject *
@@ -1372,7 +1415,9 @@ ggv_postscript_view_add_interfaces (GgvPostScriptView *ps_view,
 
 	/* Interface Bonobo::PersistStream */
 	stream = bonobo_persist_stream_new (load_ps_from_stream, 
-										NULL, NULL, NULL, ps_view);
+										NULL, NULL,
+										"OAFIID:GNOME_GGV_PostScriptView",
+										ps_view);
 	if (!stream) {
 		bonobo_object_unref (BONOBO_OBJECT (to_aggregate));
 		return NULL;
@@ -1395,11 +1440,11 @@ ggv_postscript_view_add_interfaces (GgvPostScriptView *ps_view,
 	/* BonoboItemContainer */
 	item_container = bonobo_item_container_new ();
 
-	gtk_signal_connect (GTK_OBJECT (item_container),
-						"get_object",
-						GTK_SIGNAL_FUNC (ggv_postscript_view_get_object),
-						ps_view);
-
+	g_signal_connect (G_OBJECT (item_container),
+					  "get_object",
+					  G_CALLBACK (ggv_postscript_view_get_object),
+					  ps_view);
+	
 	bonobo_object_add_interface (BONOBO_OBJECT (to_aggregate),
 								 BONOBO_OBJECT (item_container));
 
@@ -1525,6 +1570,7 @@ GNOME_GGV_Orientation
 ggv_postscript_view_get_default_orientation(GgvPostScriptView *ps_view)
 {
 	BonoboArg *arg;
+	GNOME_GGV_Orientation orient;
 
 	g_return_val_if_fail(ps_view != NULL, 0);
 	g_return_val_if_fail(GGV_IS_POSTSCRIPT_VIEW(ps_view), 0);
@@ -1535,7 +1581,9 @@ ggv_postscript_view_get_default_orientation(GgvPostScriptView *ps_view)
 		return 0;
 
 	g_assert(arg->_type == TC_GNOME_GGV_Orientation);
-	return *(GNOME_GGV_Orientation *) arg->_value;
+	orient = *(GNOME_GGV_Orientation *) arg->_value;
+	bonobo_arg_release(arg);
+	return orient;
 }
 
 static void
@@ -1548,30 +1596,31 @@ ggv_postscript_view_destroy(BonoboObject *object)
 
 	ps_view = GGV_POSTSCRIPT_VIEW(object);
 
+	if (ps_view->priv->gconf_notify_id) {
+		gconf_client_notify_remove (gtk_gs_defaults_gconf_client (),
+									ps_view->priv->gconf_notify_id);
+		ps_view->priv->gconf_notify_id = 0;
+	}
 	if(ps_view->priv->property_bag) {
 		bonobo_object_unref(BONOBO_OBJECT(ps_view->priv->property_bag));
 		ps_view->priv->property_bag = NULL;
 	}
-
-	if(ps_view->priv->property_control) {
-		bonobo_object_unref(BONOBO_OBJECT(ps_view->priv->property_control));
-		ps_view->priv->property_control = NULL;
-	}
-
 	if(ps_view->priv->gs) {
-		gtk_widget_destroy(ps_view->priv->gs);
+		gtk_widget_unref(ps_view->priv->gs);
 		ps_view->priv->gs = NULL;
 	}
-
 	if(ps_view->priv->msg_win) {
 		ggv_msg_window_free(ps_view->priv->msg_win);
 		ps_view->priv->msg_win = NULL;
 	}
-
 	if(ps_view->priv->uic) {
 		bonobo_object_unref(BONOBO_OBJECT(ps_view->priv->uic));
 		ps_view->priv->uic = NULL;
 	}
+	if(ps_view->priv->sidebar) {
+		bonobo_object_unref(BONOBO_OBJECT(ps_view->priv->sidebar));
+		ps_view->priv->sidebar = NULL;
+	}
 
 	if (BONOBO_OBJECT_CLASS (ggv_postscript_view_parent_class)->destroy)
 		BONOBO_OBJECT_CLASS(ggv_postscript_view_parent_class)->destroy(object);
@@ -1633,6 +1682,16 @@ impl_GNOME_GGV_PostScriptView_getPages(PortableServer_Servant servant,
 	return retval;
 }
 
+static void
+impl_GNOME_GGV_PostScriptView_reload(PortableServer_Servant servant,
+									   CORBA_Environment *ev)
+{
+	GgvPostScriptView *ps_view;
+
+	ps_view = GGV_POSTSCRIPT_VIEW(bonobo_object_from_servant(servant));
+	gtk_gs_reload(GTK_GS(ps_view->priv->gs));
+}
+
 static void
 ggv_postscript_view_class_init(GgvPostScriptViewClass *klass)
 {
@@ -1651,6 +1710,7 @@ ggv_postscript_view_class_init(GgvPostScriptViewClass *klass)
 
 	epv->getDocument = impl_GNOME_GGV_PostScriptView_getDocument;
 	epv->getPages = impl_GNOME_GGV_PostScriptView_getPages;
+	epv->reload = impl_GNOME_GGV_PostScriptView_reload;
 
 	/* this seems as a nice place to load the prefs */
 	ggv_prefs_load();
@@ -1667,6 +1727,7 @@ BONOBO_TYPE_FUNC_FULL(GgvPostScriptView,
 					  BONOBO_TYPE_OBJECT,
 					  ggv_postscript_view);
 
+#if 0
 static void
 property_control_get_prop(BonoboPropertyBag *bag,
 						  BonoboArg         *arg,
@@ -1683,15 +1744,13 @@ property_control_get_prop(BonoboPropertyBag *bag,
 		g_assert_not_reached();
 	}
 }
+#endif
 
 static BonoboControl *
 property_control_get_cb(BonoboPropertyControl *property_control,
 						int page_number, void *closure)
 {
 	GgvPostScriptView *ps_view;
-	GtkWidget *container;
-	BonoboControl *control;
-	BonoboPropertyBag *property_bag;
 
 	g_return_val_if_fail(closure != NULL, NULL);
 	g_return_val_if_fail(GGV_IS_POSTSCRIPT_VIEW(closure), NULL);
@@ -1726,12 +1785,10 @@ property_control_get_cb(BonoboPropertyControl *property_control,
 static void
 document_changed_cb(GtkGS *gs, gpointer data)
 {
-	GgvPostScriptView *ps_view = GGV_POSTSCRIPT_VIEW(data);
-	gchar *fname;
-
-	fname = g_strdup(GTK_GS(ps_view->priv->gs)->gs_filename);
-	gtk_gs_load(GTK_GS(ps_view->priv->gs), fname);
-	g_free(fname);				
+	gtk_gs_reload(gs);
+	notify_page_count_change(GGV_POSTSCRIPT_VIEW(data));
+	notify_page_change(GGV_POSTSCRIPT_VIEW(data));
+	notify_status_change(GGV_POSTSCRIPT_VIEW(data));
 }
 
 static void
@@ -1739,8 +1796,11 @@ interpreter_message_cb(GtkGS *gs, gchar *msg, gpointer data)
 {
 	GgvPostScriptView *ps_view = GGV_POSTSCRIPT_VIEW(data);
 
+#if 0
+	/* actually, these are quite useless, so we won't show them... */
 	if(ps_view->priv->msg_win)
 		ggv_msg_window_add_text(ps_view->priv->msg_win, msg, TRUE);
+#endif
 
 #ifdef BONOBO_DEBUG
 	g_warning(msg);
@@ -1753,6 +1813,7 @@ interpreter_error_cb(GtkGS *gs, gint status, gpointer data)
 	notify_title_change(GGV_POSTSCRIPT_VIEW(data));
 	notify_page_change(GGV_POSTSCRIPT_VIEW(data));
 	notify_page_count_change(GGV_POSTSCRIPT_VIEW(data));
+	notify_status_change(GGV_POSTSCRIPT_VIEW(data));
 }
 
 static void
@@ -1765,6 +1826,53 @@ view_realized_cb(GtkGS *gs, gpointer data)
 	gdk_cursor_destroy(cursor);
 }
 
+static void
+ggv_postscript_view_prefs_changed(GConfClient *client, guint cnxn_id,
+								  GConfEntry *entry, gpointer user_data)
+{
+	GgvPostScriptView *ps_view = GGV_POSTSCRIPT_VIEW(user_data);
+	GtkGS *gs = GTK_GS(ps_view->priv->gs);
+
+	if(!strcmp(entry->key, "/apps/ggv/gtkgs/respect_eof")) 
+		gtk_gs_set_respect_eof(gs, gconf_client_get_bool(client, "/apps/ggv/gtkgs/respect_eof", NULL));
+	else if(!strcmp(entry->key, "/apps/ggv/gtkgs/override_orientation")) {
+		gtk_gs_set_override_orientation(gs, gconf_client_get_bool(client, "/apps/ggv/gtkgs/override_orientation",
+																  NULL));
+		sync_orientation_items(ps_view);
+	}
+	else if(!strcmp(entry->key, "/apps/ggv/gtkgs/orientation")) {
+		gtk_gs_set_default_orientation(gs, gconf_client_get_int(client, "/apps/ggv/gtkgs/orientation",
+																NULL));
+		sync_orientation_items(ps_view);
+	}
+#if 0
+	else if(!strcmp(entry->key, "/apps/ggv/gtkgs/zoom")) {
+		gtk_gs_set_zoom(gs, gconf_client_get_float(client, "/apps/ggv/gtkgs/zoom",
+												   NULL));
+	}
+#endif
+	else if(!strcmp(entry->key, "/apps/ggv/gtkgs/size")) {
+		gtk_gs_set_default_size(gs, gconf_client_get_int(client, "/apps/ggv/gtkgs/size",
+														 NULL));
+		sync_size_items(ps_view);
+	}
+	else if(!strcmp(entry->key, "/apps/ggv/gtkgs/antialiasing"))
+		gtk_gs_set_antialiasing(gs, gconf_client_get_bool(client, "/apps/ggv/gtkgs/antialiasing",
+														  NULL));
+	else if(!strcmp(entry->key, "/apps/ggv/gtkgs/override_size")) {
+		gtk_gs_set_override_size(gs, gconf_client_get_bool(client, "/apps/ggv/gtkgs/override_size",
+														   NULL));
+		sync_size_items(ps_view);
+	}
+	else if(!strcmp(entry->key, "/apps/ggv/gtkgs/watch_doc"))
+		gtk_gs_set_watch_file(gs, gconf_client_get_bool(client, "/apps/ggv/gtkgs/watch_doc",
+														NULL));
+	else if(!strcmp(entry->key, "/apps/ggv/gtkgs/show_scroll_rect"))
+		gtk_gs_set_show_scroll_rect(gs, gconf_client_get_bool(client, "/apps/ggv/gtkgs/show_scroll_rect",
+															  NULL));
+}
+
+
 GgvPostScriptView *
 ggv_postscript_view_construct(GgvPostScriptView *ps_view,
 							  GtkGS *gs, gboolean zoom_fit)
@@ -1776,9 +1884,17 @@ ggv_postscript_view_construct(GgvPostScriptView *ps_view,
 	g_return_val_if_fail(!GTK_WIDGET_REALIZED(gs), NULL);
 
 	/* Make sure GConf is initialized */
-	if(!gconf_is_initialized())
+	if(!gconf_is_initialized()) {
 		gconf_init(0, NULL, NULL);
-	
+	}
+
+	ps_view->priv->gconf_notify_id =
+		gconf_client_notify_add(gtk_gs_defaults_gconf_client(),
+								"/apps/ggv/gtkgs",
+								(GConfClientNotifyFunc)ggv_postscript_view_prefs_changed,
+								ps_view, NULL, NULL);
+															 
+
 	ps_view->priv->msg_win = ggv_msg_window_new(_("GhostScript output"));
 
 	ps_view->priv->gs = GTK_WIDGET(gs);
@@ -1879,8 +1995,6 @@ ggv_postscript_view_construct(GgvPostScriptView *ps_view,
 	/* UI Component */
 	ps_view->priv->uic = bonobo_ui_component_new("GgvPostScriptView");
 
-	ggv_postscript_view_add_interfaces (ps_view, BONOBO_OBJECT (ps_view));
-
 	ps_view->priv->sidebar = ggv_sidebar_new(ps_view);
 
 	return ps_view;
@@ -1916,5 +2030,5 @@ ggv_postscript_view_set_popup_ui_component(GgvPostScriptView *ps_view,
 										   BonoboUIComponent *uic)
 {
 	ps_view->priv->popup_uic = uic;
-	_set_page_item_sensitivity(ps_view, uic);
+	_set_page_items_sensitivity(ps_view, uic);
 }
