@@ -92,6 +92,7 @@ sync_settings_menu_items(GgvWindow *win)
         if(win->uic == NULL)
                 return;
 
+	bonobo_ui_component_freeze(win->uic, NULL);
         bonobo_ui_component_set_prop(win->uic, "/commands/SettingsShowMenus", "state",
                                      win->show_menus?"1":"0", NULL);
         bonobo_ui_component_set_prop(win->uic, "/commands/SettingsShowToolbar", "state",
@@ -100,6 +101,7 @@ sync_settings_menu_items(GgvWindow *win)
                                      win->show_sidebar?"1":"0", NULL);
         bonobo_ui_component_set_prop(win->uic, "/commands/SettingsShowStatusbar", "state",
                                      win->show_statusbar?"1":"0", NULL);
+	bonobo_ui_component_thaw(win->uic, NULL);
 }
 
 static void
@@ -108,6 +110,7 @@ sync_settings_popup_items(GgvWindow *win)
         if(win->popup_uic == NULL)
                 return;
 
+	bonobo_ui_component_freeze(win->popup_uic, NULL);
         bonobo_ui_component_set_prop(win->popup_uic, "/commands/SettingsShowMenus", "state",
                                      win->show_menus?"1":"0", NULL);
         bonobo_ui_component_set_prop(win->popup_uic, "/commands/SettingsShowToolbar", "state",
@@ -116,6 +119,7 @@ sync_settings_popup_items(GgvWindow *win)
                                      win->show_sidebar?"1":"0", NULL);
         bonobo_ui_component_set_prop(win->popup_uic, "/commands/SettingsShowStatusbar", "state",
                                      win->show_statusbar?"1":"0", NULL);
+	bonobo_ui_component_thaw(win->popup_uic, NULL);
 }
 
 void
@@ -187,14 +191,23 @@ control_property_changed_handler(BonoboListener    *listener,
                 win->current_page = BONOBO_ARG_GET_LONG(any);
                 if(win->current_page < 0) {
                         GtkWidget *dlg;
+                        BonoboArg *arg;
+                        gchar *msg;
+
+                        arg = bonobo_pbclient_get_value(win->pb, "status",
+                                                        NULL, NULL);
+                        if(arg == NULL)
+                                return;
+                        msg = BONOBO_ARG_GET_STRING(arg);
                         dlg = gtk_message_dialog_new(GTK_WINDOW(win),
                                                      GTK_DIALOG_MODAL,
                                                      GTK_MESSAGE_ERROR,
                                                      GTK_BUTTONS_OK,
-                                                     _("Ghostscript error:\nProbably the file is not a PostScript file."));
+                                                     msg);
                         gtk_widget_show(dlg);
                         gtk_dialog_run(GTK_DIALOG(dlg));
                         gtk_widget_destroy(dlg);
+                        bonobo_arg_release(arg);
                         return;
                 }
         }
@@ -408,6 +421,14 @@ verb_HelpAbout(BonoboUIComponent *uic, gpointer data, const char *cname)
                 "And many more...",
  		NULL
 	};
+
+	static const char *documenters[] = {
+		NULL
+	};
+
+	/* Translator Credits */
+	char *translator_credits = _("translator_credits");
+
         static GdkPixbuf *logo = NULL;
 
         if(!logo)
@@ -421,8 +442,8 @@ verb_HelpAbout(BonoboUIComponent *uic, gpointer data, const char *cname)
 			_("Copyright (C) 1998-2002 The Free Software Foundation"),
 			_("The GNOME PostScript document previewer"),
 			authors,
-			NULL, /* char **documentors */
-			NULL, /* char *translators */
+			documenters,
+			strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 			logo);
                 gtk_window_set_transient_for(GTK_WINDOW(about),
                                              GTK_WINDOW(data));
