@@ -350,6 +350,8 @@ gtk_gs_init (GtkGS *gs)
         gs->show_scroll_rect = gtk_gs_defaults_get_show_scroll_rect();
 
         gs->scroll_start_x = gs->scroll_start_y = -1;
+
+        gs->gs_status = _("No document loaded.");
 }
 
 static void
@@ -465,7 +467,7 @@ gtk_gs_cleanup (GtkGS *gs)
  		gtk_timeout_remove (gs->timer_tag);
  		gs->timer_tag = 0;
  	}
-        if(!gdk_window_is_visible(gs->pstarget))
+        if(gs->pstarget && !gdk_window_is_visible(gs->pstarget))
                 gdk_window_hide(gs->pstarget);
         gs->current_page = -1;
         gs->loaded = FALSE;
@@ -481,6 +483,7 @@ static void
 gtk_gs_interpreter_message(GtkGS *gs, gchar *msg, gpointer user_data)
 {
         if(strstr(msg, "Error:")) {
+                gs->gs_status = _("File is not a valid PostScript document.");
                 gtk_gs_cleanup(gs);
                 g_signal_emit_by_name(G_OBJECT(gs), "interpreter_error",
                                       1, NULL);
@@ -573,19 +576,10 @@ gtk_gs_munge_adjustments (GtkGS *gs)
 		gs->vadj->value = -((gfloat)y)/gs->height;
 	}
 
-        if(gs->scroll_start_x != -1 && gs->scroll_start_y != -1) {
-                gdk_draw_rectangle(gs->pstarget, gs->psgc, FALSE,
-                                   gs->scroll_start_x, gs->scroll_start_y,
-                                   gs->scroll_width, gs->scroll_height);
-        }
 	gdk_window_move(gs->pstarget, x, y);
         while(gtk_events_pending()) {
                 gtk_main_iteration();
         }
-        if(gs->scroll_start_x != -1 && gs->scroll_start_y != -1)
-                gdk_draw_rectangle(gs->pstarget, gs->psgc, FALSE,
-                                   gs->scroll_start_x, gs->scroll_start_y,
-                                   gs->scroll_width, gs->scroll_height);
 
 	gtk_adjustment_changed (gs->hadj);
 	gtk_adjustment_changed (gs->vadj);
@@ -744,18 +738,10 @@ gtk_gs_value_adjustment_changed (GtkAdjustment *adjustment, gpointer data)
         else
                 newy = -gs->vadj->value*gs->height;
 
-        if(gs->scroll_start_x != -1 && gs->scroll_start_y != -1)
-                gdk_draw_rectangle(gs->pstarget, gs->psgc, FALSE,
-                                   gs->scroll_start_x, gs->scroll_start_y,
-                                   gs->scroll_width, gs->scroll_height);
         gdk_window_move(gs->pstarget, newx, newy);
         while(gtk_events_pending()) {
                 gtk_main_iteration();
         }
-        if(gs->scroll_start_x != -1 && gs->scroll_start_y != -1)
-                gdk_draw_rectangle(gs->pstarget, gs->psgc, FALSE,
-                                   gs->scroll_start_x, gs->scroll_start_y,
-                                   gs->scroll_width, gs->scroll_height);
 }
 
 void
@@ -862,6 +848,9 @@ set_up_page (GtkGS *gs)
         char *savelocale;
 #endif
 
+        if(!GTK_WIDGET_REALIZED(gs))
+                return;
+
         /* Do we have to check if the actual geometry changed? */
         
         stop_interpreter(gs);
@@ -1255,6 +1244,7 @@ stop_interpreter (GtkGS *gs)
                 wait(&status);
                 if(status == 1) {
                         gtk_gs_cleanup(gs);
+                        gs->gs_status = _("Interpreter failed.");
                         g_signal_emit_by_name(G_OBJECT(gs), "interpreter_error",
                                               status);
                 }
@@ -1618,12 +1608,15 @@ gtk_gs_reload(GtkGS *gs)
 	gchar *fname;
 	gfloat hval = gs->hadj->value;
 	gfloat vval = gs->vadj->value;
+        gint page;
 
         if(!gs->gs_filename)
                 return;
 
+        page = gtk_gs_get_current_page(gs);
 	fname = g_strdup(gs->gs_filename);
 	gtk_gs_load(gs, fname);
+        gtk_gs_goto_page(gs, page);
 	gtk_adjustment_set_value(gs->hadj, hval);
 	gtk_adjustment_set_value(gs->vadj, vval);
 	g_free(fname);				
@@ -1648,20 +1641,12 @@ gtk_gs_center_page(GtkGS *gs)
 	g_return_if_fail (gs != NULL);
 	g_return_if_fail (GTK_IS_GS(gs));
 
-        if(gs->scroll_start_x != -1 && gs->scroll_start_y != -1)
-                gdk_draw_rectangle(gs->pstarget, gs->psgc, FALSE,
-                                   gs->scroll_start_x, gs->scroll_start_y,
-                                   gs->scroll_width, gs->scroll_height);
         gdk_window_move(gs->pstarget,
                         (gs->widget.allocation.width - gs->width)/2,
                         (gs->widget.allocation.height - gs->height)/2);
         while(gtk_events_pending()) {
                 gtk_main_iteration();
         }
-        if(gs->scroll_start_x != -1 && gs->scroll_start_y != -1)
-                gdk_draw_rectangle(gs->pstarget, gs->psgc, FALSE,
-                                   gs->scroll_start_x, gs->scroll_start_y,
-                                   gs->scroll_width, gs->scroll_height);
         gs->hadj->page_size = ((gfloat) gs->widget.allocation.width)/gs->width;
         gs->hadj->page_size = MIN(gs->hadj->page_size, 1.0);
         gs->vadj->page_size = ((gfloat) gs->widget.allocation.height)/gs->height;
@@ -1701,7 +1686,6 @@ gtk_gs_disable_interpreter (GtkGS *gs)
 		stop_interpreter (gs);
 }
 
-
 gboolean
 gtk_gs_load (GtkGS *gs, const gchar *fname)
 {
@@ -1750,8 +1734,9 @@ gtk_gs_load (GtkGS *gs, const gchar *fname)
 		if (!ggv_file_readable (fname)) {
 			gchar buf[1024];
 			g_snprintf (buf, 1024,
-				    _("Cannot open file %s\n"), fname);
+				    _("Cannot open file %s.\n"), fname);
 			gtk_gs_emit_error_msg (gs, buf);
+                        gs->gs_status = _("File is not readable.");
 		} else {
                         filename = check_filecompressed (gs);
 			if (filename)
@@ -1775,6 +1760,7 @@ gtk_gs_load (GtkGS *gs, const gchar *fname)
 				    _("Error while scanning file %s\n"), fname);
 			gtk_gs_emit_error_msg (gs, buf);
                         gtk_gs_cleanup (gs);
+                        gs->gs_status = _("The file is not a PostScript document.");
                         return FALSE;
                 }
 
@@ -1814,6 +1800,8 @@ gtk_gs_load (GtkGS *gs, const gchar *fname)
                                                 timer_callback, gs);
 	}
 
+        gs->gs_status = _("Document loaded.");
+
 	return gs->loaded;
 }
 
@@ -2384,9 +2372,17 @@ gtk_gs_start_scroll(GtkGS *gs)
         gs->scroll_width = MIN(gs->widget.allocation.width - 1, w - 1);
         gs->scroll_height = MIN(gs->widget.allocation.height - 1, h - 1);
 
-        gdk_draw_rectangle(gs->pstarget, gs->psgc, FALSE,
-                           gs->scroll_start_x, gs->scroll_start_y,
-                           gs->scroll_width, gs->scroll_height);
+        if(gs->bpixmap) {
+                GdkRectangle rect;
+                rect.x = gs->scroll_start_x;
+                rect.y = gs->scroll_start_y;
+                rect.width = gs->scroll_width + 1;
+                rect.height = gs->scroll_height + 1;
+                gdk_draw_rectangle(gs->bpixmap, gs->psgc, FALSE,
+                                   gs->scroll_start_x, gs->scroll_start_y,
+                                   gs->scroll_width, gs->scroll_height);
+                gdk_window_invalidate_rect(gs->pstarget, &rect, TRUE);
+        }
 }
 
 void
@@ -2398,9 +2394,17 @@ gtk_gs_end_scroll(GtkGS *gs)
         if(gs->scroll_start_x == -1 || gs->scroll_start_y == -1)
                 return;
 
-        gdk_draw_rectangle(gs->pstarget, gs->psgc, FALSE,
-                           gs->scroll_start_x, gs->scroll_start_y,
-                           gs->scroll_width, gs->scroll_height);
+        if(gs->bpixmap) {
+                GdkRectangle rect;
+                rect.x = gs->scroll_start_x;
+                rect.y = gs->scroll_start_y;
+                rect.width = gs->scroll_width + 1;
+                rect.height = gs->scroll_height + 1;
+                gdk_draw_rectangle(gs->bpixmap, gs->psgc, FALSE,
+                                   gs->scroll_start_x, gs->scroll_start_y,
+                                   gs->scroll_width, gs->scroll_height);
+                gdk_window_invalidate_rect(gs->pstarget, &rect, TRUE);
+        }
         gs->scroll_start_x = -1;
         gs->scroll_start_y = -1;
 }
